@@ -17,15 +17,19 @@ class SourceServer(object):
 		self.TIME_UNTIL_RETRY = float(3)
 		self.isClosed = False
 
+		# A tuple that lines up with the mode numbers for The Ship
+		self.MODES = ("Hunt", "Elimination", "Duel", "Deathmatch", "VIP Team", "Team Elimination")
+
 		if not self._validConString(connectionString): raise ValueError("Connection string invalid")
 
 		# Init socket
 		self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
 		self.socket.setblocking(0)
 
-		# Set IP and port
-		self.ip, self.port = connectionString.split(":")
-		self.port = int(self.port)
+		# Set up connection
+		self._ip, self._port = connectionString.split(":")
+		self._port = int(self._port)
+		self.socket.connect((self._ip, self._port))
 
 		try: self._connect()
 		except SourceError:
@@ -38,7 +42,7 @@ class SourceServer(object):
 		return self._getInfo()
 
 	def _log(self, *args):
-		print("Source Server @ ", self.ip, ":", self.port, " | ", *args, sep="")
+		print("Source Server @ ", self._ip, ":", self._port, " | ", *args, sep="")
 
 	def _validConString(self, conString: str) -> bool:
 		'''Validates a connection string'''
@@ -70,7 +74,7 @@ class SourceServer(object):
 			self._log("Failed to reconnect")
 		else: self._log("Reconnected successfully")
 
-	def ping(self, places=0):
+	def ping(self, places: int = 0) -> float:
 		'''
 		Times an info request to the server and returns it in miliseconds\n
 		places is how many decimal places to round the ping to, default is 0
@@ -94,7 +98,7 @@ class SourceServer(object):
 	def _request(self, request: bytes) -> bytes:
 		'''Makes a UDP request and returns response as bytes'''
 		if self.isClosed: raise SourceError(self, "Request attempt made on closed connection")
-		self.socket.sendto(request, (self.ip, self.port))
+		self.socket.sendall(request)
 		return self._response()
 	
 	def _packetSplit(self, packet: bytes) -> bool:
